

C        *** NLMFE8 ***
C        MODULAR FINITE-ELEMENT MODEL OF GROUND-WATER FLOW
C        IN TWO DIMENSIONS.
C        SIMULATES THE FOLLOWING CONDITIONS:
C        (1) UNCONFINED FLOW
C        (2) AQUIFER STORAGE CONVERSIONS
C        (3) NONLINEAR CAUCHY-TYPE BOUNDARIES AND (OR) NONLINEAR POINT
C            SINKS
C        USES MODIFIED, INCOMPLETE CHOLESKY, CONJUGATE GRADIENT METHOD
C        TO SOLVE MATRIX EQUATIONS.
      DIMENSION TITLE(20)
      COMMON/PRIME/G(5000)
      COMMON/GDIM/ISUM
      COMMON/ADR/IAA,IARA,IXGA,IYGA,IATA,IQA,IBA,IHA,IHRA,IHBA,IALA,IQBA
     1,ICKA,ICLA,IHKA,IHLA,IDTA,IJPA,INA,INDA,IKA,ILA,IDZA,IDSA
      COMMON/NO/NELS,NNDS,NSTEPS,NPER,NZNS,NWELS,NQBND,NHDS,NEQ,MBWC,NIT
      COMMON/CHG/NWCH,NQCH,NHRCH,NBQCH,NHCH,NCBCH,NVNCH,NGNCH
      COMMON/ITP/IIN,IOUT,ITA,ITB
      COMMON/IPRN/IPND
      COMMON/IND/IRAD,IUNIT,ISTD
      COMMON/SCLE/SCALE
      COMMON/BAL/SA,WQI,WQO,DQI,DQO,VLQI,VLQO,BQI,BQO,ER
      COMMON/TBAL/TSA,TWQI,TWQO,TDQI,TDQO,TLQI,TLQO,TBQI,TBQO,THBQI
     1,THBQO,TER
      COMMON/VNLBL/VNLQI,VNLQO,TNLQI,TNLQO
      COMMON/GNBL/BNQI,BNQO,TBNQI,TBNQO,PNQO,TPNQO
C
C     set string for use if RCS ident command
      CHARACTER*80 vr
      vr =
     &'$Id: nlmfe8.main.f,v 1.2 1995/08/08 16:31:11 rsregan Exp $'
C     set string for use with UNIX what command
      vr = '@(#)MODFE - MODular Finite-Element ground-water flow model'
      vr = '@(#)MODFE - USGS TWRI Book 6, Chapter A3, 1993 L.J. Torak'
      vr = '@(#)MODFE - USGS TWRI Book 6, Chapter A4, 1992, R.L. Cooley'
      vr = '@(#)MODFE - USGS TWRI Book 6, Chapter A5, 1993 L.J. Torak'
      vr = '@(#)MODFE - Contact: h2osoft@usgs.gov'
      vr = '@(#)MODFE - Version: 1.2x 1995/08/08'
C
      OPEN (50,FILE='MODFE.DAT',STATUS='OLD',ACCESS='SEQUENTIAL'
     1,FORM='FORMATTED')
      OPEN (60,FILE='MODFE.OUT',STATUS='NEW',ACCESS='SEQUENTIAL'
     1,FORM='FORMATTED')
      OPEN (55,STATUS='SCRATCH',ACCESS='SEQUENTIAL',FORM='UNFORMATTED')
      OPEN (56,STATUS='SCRATCH',ACCESS='SEQUENTIAL',FORM='UNFORMATTED')
    6 FORMAT(/9X,'SUMMARY OF FLOW AT CAUCHY-TYPE BOUNDARIES BY ZONE')
    7 FORMAT(/4X,'SUMMARY OF FLOW AT NONLINEAR CAUCHY-TYPE BOUNDARIES',
     1' BY ZONE')
      CALL INITCG(TITLE,G,TIME,TOL,IAFA,IXA,IPA,IRA,NBCZ)
      CALL WTINIT(G,IDHA,ITKA,ITPA,ISYA)
      CALL GNINIT(G,IGCA,IHRK,IHRL,IZRK,IZRL,IZPA,IKRA,ILRA,IKPA,INZA
     1,INSA,NBNC,NPNB,NLCZ)
      CALL DATIN(TITLE,G(IXGA),G(IYGA),G(IHA),G(IHBA),G(IHRA)
     1,G(IHKA),G(IHLA),G(IALA),G(IQBA),G(IQA),G(IKA),G(ILA),G(INA)
     2,G(IDZA),G(IDSA),NBCZ)
      CALL FMCO(G(IXGA),G(IYGA),G(IAA),G(IQA),G(IARA),G(IALA),G(IQBA)
     1,G(ICKA),G(ICLA),G(INDA),G(IBA),G(IJPA),G(IKA),G(ILA))
      CALL WTFMCO(G(IARA),G(ITKA),G(ITPA),G(ISYA),G(INDA))
      CALL GNFMCO(G(IXGA),G(IYGA),G(IGCA),G(IHRK),G(IHRL),G(IZRK)
     1,G(IZRL),G(IZPA),G(IKRA),G(ILRA),G(IKPA),G(INZA),G(INSA),NBNC
     2,NPNB,NLCZ)
      CALL SETCG(G(IAA))
      DO 20 JP=1,NPER
      JPER=JP
      CALL NXTPD(G(IDTA),JPER)
      DO 10 I=1,NSTEPS
      ISTP=I
      DT=G(IDTA+I-1)
      CALL COCHG(G(IQA),G(IARA),G(IHA),G(IHRA),G(IHBA),G(IHKA),G(IHLA)
     1,G(IALA),G(IQBA),G(ICKA),G(ICLA),TIME,G(IKA),G(ILA),G(INDA),G(INA)
     2,ISTP)
      IF(NGNCH.EQ.ISTP) CALL GNCHG(G(IHRK),G(IHRL),TIME,G(IKRA),G(ILRA)
     1,ISTP)
      CALL RDTP(G(IAA))
      CALL FMEPWT(G(IHA),G(IHRA),G(IHKA),G(IHLA),G(ICKA),G(ICLA),G(IAA)
     1,G(IARA),G(IQA),G(IBA),G(ITKA),G(ITPA),G(ISYA),DT,G(IJPA),G(INA)
     2,G(IKA),G(ILA))
      CALL GNPRED(G(IHA),G(IAA),G(IBA),G(IGCA),G(IHRK),G(IHRL),G(IZRK)
     1,G(IZRL),G(IZPA),G(INA),G(IKRA),G(ILRA),G(IKPA),NBNC,NPNB)
      CALL MICCG(G(IAA),G(IAFA),G(IXA),G(IPA),G(IRA),G(IBA),TOL,G(IJPA)
     1,G(INA))
      CALL HCALWT(G(IHA),G(IDHA),G(IBA),G(INA))
      CALL RDTP(G(IAA))
      CALL FMECWT(G(IHA),G(IDHA),G(IHBA),G(IHRA),G(IHKA),G(IHLA),G(ICKA)
     1,G(ICLA),G(IAA),G(IARA),G(IQA),G(IBA),G(ITKA),G(IYGA),G(ITPA)
     2,G(ISYA),DT,G(IJPA),G(INA),G(IKA),G(ILA))
      CALL GNCORR(G(IHA),G(IDHA),G(IAA),G(IBA),G(IGCA),G(IHRK),G(IHRL)
     1,G(IZRK),G(IZRL),G(IZPA),G(INA),G(IKRA),G(ILRA),G(IKPA),NBNC,NPNB)
      CALL MICCG(G(IAA),G(IAFA),G(IXA),G(IPA),G(IRA),G(IBA),TOL,G(IJPA)
     1,G(INA))
      CALL WTCCHK(G(IHA),G(IDHA),G(IBA),G(ITPA),G(INA),ISC)
      IF(ISC.EQ.0) GO TO 5
      CALL HCALWT(G(IHA),G(IDHA),G(IBA),G(INA))
      CALL RDTP(G(IAA))
      CALL FMECWT(G(IHA),G(IDHA),G(IHBA),G(IHRA),G(IHKA),G(IHLA),G(ICKA)
     1,G(ICLA),G(IAA),G(IARA),G(IQA),G(IBA),G(ITKA),G(IYGA),G(ITPA)
     2,G(ISYA),DT,G(IJPA),G(INA),G(IKA),G(ILA))
      CALL GNCORR(G(IHA),G(IDHA),G(IAA),G(IBA),G(IGCA),G(IHRK),G(IHRL)
     1,G(IZRK),G(IZRL),G(IZPA),G(INA),G(IKRA),G(ILRA),G(IKPA),NBNC,NPNB)
      CALL MICCG(G(IAA),G(IAFA),G(IXA),G(IPA),G(IRA),G(IBA),TOL,G(IJPA)
     1,G(INA))
    5 CALL HCALWT(G(IHA),G(IDHA),G(IBA),G(INA))
      CALL RDTP(G(IAA))
      CALL MBALWT(G(IHA),G(IDHA),G(IHBA),G(IHRA),G(IHKA),G(IHLA)
     1,G(IQBA),G(ICKA),G(ICLA),G(IAA),G(IQA),G(IYGA),G(IXGA),G(ITKA)
     2,G(IARA),G(ITPA),G(ISYA),DT,G(IJPA),G(INA),G(IKA),G(ILA))
      IF(NQBND.LT.1) GO TO 8
      WRITE(IOUT,6)
      CALL PRTCBV(G(IARA),G(IXGA),DT,G(IKA),G(ILA),G(IDZA),G(IDSA),NBCZ)
    8 CALL GNBAL(G(IHA),G(IDHA),G(IHBA),G(IYGA),G(IGCA),G(IHRK),G(IHRL)
     1,G(IZRK),G(IZRL),G(IZPA),G(IARA),G(IXGA),DT,G(INA),G(IKRA),G(ILRA)
     2,G(IKPA),NBNC,NPNB)
      IF(NLCZ.LT.1) GO TO 9
      WRITE(IOUT,7)
      CALL PRTCBV(G(IARA),G(IXGA),DT,G(IKRA),G(ILRA),G(INZA),G(INSA)
     1,NLCZ)
    9 IF(ISTD.LT.1) CALL XTRPWT(G(IHA),G(IDHA),G(IHBA),G(ITKA),G(ITPA)
     1,G(INA),ISTP)
      CALL DATOUT(G(IHA),DT,TIME,ISTP)
      CALL MASOUT(G(IYGA),DT,ISTP)
   10 CONTINUE
   20 CONTINUE
      STOP
      END
