


      SUBROUTINE VNBAL(H,DH,DHB,R,TOP,E,HS,DT,IN)
C        COMPUTES FLOW-BALANCE COMPONENTS FOR NONLINEAR STEADY-
C        LEAKAGE FUNCTIONS
      DIMENSION H(1),DH(1),DHB(1),R(1),TOP(1),E(1),HS(1)
      DIMENSION IN(1)
      COMMON/NO/NELS,NNDS,NSTEPS,NPER,NZNS,NWELS,NQBND,NHDS,NEQ,MBWC,MBW
      COMMON/BAL/SA,WQI,WQO,DQI,DQO,VLQI,VLQO,BQI,BQO,ER
      COMMON/VNLBL/VNLQI,VNLQO,TNLQI,TNLQO
C *** INITIALIZE VOLUMETRIC-FLOW RATES TO ZERO ***
      VNLQI=0.
      VNLQO=0.
C *** COMPUTE WEIGHTING FACTORS FOR GALERKIN-IN-TIME FORMULATION ***
      CA=1./3.
      CB=2./3.
C *** FOR EACH NODE I ON THE LEAKAGE BOUNDARY: ***
      DO 170 I=1,NNDS
C *** (1) COMPUTE HEAD AT N LEVEL, HO, AND HEAD AT N+1 LEVEL, HC ***
      K=IN(I)
      IF(K.LT.0) GO TO 5
      DHC=DH(K)
      GO TO 10
    5 DHC=DHB(-K)
   10 HO=H(I)-DHC
      DHC=1.5*DHC
      HC=HO+DHC
C *** (2) DETERMINE FUNCTION TYPE BY SIGN OF E(I) ***
      IF(E(I)) 15,170,90
C ***
C *** DISCHARGE-ONLY TYPE ***
   15 EI=-E(I)
C *** (3) REPRESENT ELEVATIONS, AND HEAD AND ELEVATION DIFFERENCES, BY
C         TEMPORARY (UNSUBSCRIPTED) VARIABLES ***
      ZE=HS(I)
      ZT=TOP(I)
      DEH=ZE-HO
      DHT=HO-ZT
      DET=ZE-ZT
C *** (4) COMPARE HEADS WITH CONTROLLING ELEVATIONS TO IDENTIFY LEAKAGE
C         CASE. COMPUTE HEAD DIFFERENCE, TMPA, FOR VOLUMETRIC FLOW RATES
C         FOR: ***
      IF(HO.GT.ZE) GO TO 30
      IF(HC.LT.ZE) GO TO 170
      IF(HC.LT.ZT) GO TO 20
C *** CASE (9) ***
      DMHT=DEH-DHT
      PHCF=1.-CA*(DMHT*DMHT+DHT*DEH)/(DHC*DHC)
      TMPA=PHCF*DET
      GO TO 150
C *** CASE (6) ***
   20 PHC=1.-DEH/DHC
      TMPA=CB*PHC*(ZE-HC)
      GO TO 150
   30 IF(HO.LT.ZT) GO TO 40
      IF(HC.LT.ZT) GO TO 70
C *** CASE (1) ***
      TMPA=DET
      GO TO 150
   40 IF(HC.GT.ZT) GO TO 60
      IF(HC.GT.ZE) GO TO 50
C *** CASE (5) ***
      PHE=DEH/DHC
      TMPA=CA*PHE*PHE*DEH
      GO TO 150
C *** CASE (4) ***
   50 TMPA=ZE-H(I)
      GO TO 150
C *** CASE (3) ***
   60 PHT=DHT/DHC
      TMPA=DET-CA*PHT*PHT*DHT
      GO TO 150
   70 IF(HC.GT.ZE) GO TO 80
C *** CASE (8) ***
      DMHT=DEH-DHT
      PHCF=(DMHT*DMHT+DHT*DEH)/(DHC*DHC)
      TMPA=CA*PHCF*DET
      GO TO 150
C *** CASE (2) ***
   80 PHC=1.+DHT/DHC
      TMPA=DET-CB*PHC*(HC-ZT)
      GO TO 150
C ***
C *** STEADY VERTICAL-LEAKAGE TYPE ***
   90 EI=E(I)
C *** (3) REPRESENT CONTROLLING HEAD, AQUIFER TOP ELEVATION, AND
C         DIFFERENCES BY TEMPORARY (UNSUBSCRIPTED) VARIABLES ***
      HA=HS(I)
      ZT=TOP(I)
      DHT=HO-ZT
      DAT=HA-ZT
C *** (4) COMPARE HEADS WITH AQUIFER TOP TO IDENTIFY LEAKAGE CASE.
C         COMPUTE HEAD DIFFERENCE, TMPA, FOR VOLUMETRIC-FLOW RATES
C         FOR: ***
      IF(HO.LT.ZT) GO TO 130
      IF(HC.LT.ZT) GO TO 120
C *** CASE (1) ***
      TMPA=HA-H(I)
      GO TO 150
C *** CASE (2) ***
  120 PHI=DHT/DHC
      TMPA=DAT-CA*PHI*PHI*DHT
      GO TO 150
  130 IF(HC.GT.ZT) GO TO 140
C *** CASE (4) ***
      TMPA=DAT
      GO TO 150
C *** CASE (3) ***
  140 PHC=1.+DHT/DHC
      TMPA=DAT-CB*PHC*(HC-ZT)
C ***
C *** (5) COMPARE VOLUMETRIC-FLOW RATES FOR BOTH TYPES OF NONLINEAR
C         STEADY-LEAKAGE FUNCTIONS ***
  150 TMPB=EI*TMPA
C *** INCLUDE VOLUMETRIC-FLOW RATE INTO FLOW-BALANCE EQUATION AT
C     SPECIFIED-HEAD NODE ***
      IF(K.LT.0) R(-K)=R(-K)-TMPB
C *** SUM VOLUMETRIC-FLOW RATES ACCORDING TO SIGN, POSITIVE FOR
C     INFLOW ***
      IF(TMPB.LT.0.) GO TO 160
      VNLQI=VNLQI+TMPB
      GO TO 170
  160 VNLQO=VNLQO+TMPB
  170 CONTINUE
C *** COMPUTE TOTAL VOLUMES RECHARGED (+) AND DISCHARGED (-) ACROSS
C     BOUNDARY FOR ENTIRE SIMULATION ***
      TNLQI=TNLQI+VNLQI*DT
      TNLQO=TNLQO+VNLQO*DT
C *** INCLUDE VOLUMETRIC-FLOW RATES IN THE FLOW IMBALANCE ***
      ER=ER-VNLQI-VNLQO
      RETURN
      END
